gibberish-microservice

command module
v0.0.0-...-ead23e2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 3, 2021 License: MIT Imports: 11 Imported by: 0

README

Gibberish Microservice

REST-powered microservice for analyzing text and returning if it is likely gibberish or not. The repository also contains a client to perform requests to the service.

It is important to notice that this service provides no support for authentication or caching. It is also completely stateless, making it ideal to be used in the backend. A possible "frontend" implementation can be found in Analysis API.

Endpoints

  • Gibberish endpoint: <bind-address>/gibberish
  • Health check: <bind-address>/healthy

Returned data

The data returned by the server is in the form:

type GibberishResponse struct {
    IsGibberish bool
}

Environment options

  • Service bind address and port: "GB_BIND_ADDRESS" (defaults to localhost:10002).
  • Path to knowledge base file: GB_KNOWLEDGE_PATH (defaults to knowledge.json).

Documentation

The Go Gopher

There is no documentation for this package.

Directories

Path Synopsis

Jump to